@@ -10,7 +10,7 @@
 # ABSTRACT: Generates pod doc from model files
 
 package App::Cme::Command::gen_class_pod ;
-$App::Cme::Command::gen_class_pod::VERSION = '0.001';
+$App::Cme::Command::gen_class_pod::VERSION = '1.001';
 use strict;
 use warnings;
 use 5.10.1;
@@ -18,6 +18,11 @@ use 5.10.1;
 use App::Cme -command ;
 use Config::Model::Utils::GenClassPod;
 
+sub command_names {
+    my $self = shift ;
+    return ( 'gen-class-pod' , $self->SUPER::command_names );
+}
+
 sub description {
     return << "EOD"
 Generate pod documentation from configuration models found in ./lib directory
@@ -43,7 +48,7 @@ App::Cme::Command::gen_class_pod - Generates pod doc from model files
 
 =head1 VERSION
 
-version 0.001
+version 1.001
 
 =head1 SYNOPSIS
 
